@@ -24,8 +24,9 @@ test_that("single spectrum", {
   expect_equal(sum(is.na(fred.spct[[2]])), 0)
   expect_is(fred.spct, "reflector_spct")
   expect_named(fred.spct, c("w.length", "Rfr"))
-  expect_equal(getWhereMeasured(fred.spct), 
-               data.frame(lon = NA_real_, lat = NA_real_))
+  expect_equivalent(getWhereMeasured(fred.spct), 
+                    data.frame(lon = NA_real_, lat = NA_real_, address = NA_character_, 
+                               stringsAsFactors = FALSE))
   expect_gt(length(getWhatMeasured(fred.spct)), 0)
   expect_gt(length(comment(fred.spct)), 0)
 })
